from typing import overload

import bcrypt


@overload
def encrypt_master_pass(passwd: str, salt: bytes) -> bytes:
    ...


@overload
def encrypt_master_pass(passwd: str) -> tuple[bytes, bytes]:
    ...


def encrypt_master_pass(
    passwd: str, salt: bytes | None = None
) -> tuple[bytes, bytes] | bytes:
    """Hashes master password and return tuple of hashed password and salt"""
    if salt is None:
        salt = bcrypt.gensalt()
        gened_salt = True
    else:
        gened_salt = False
    hashed = bcrypt.hashpw(passwd.encode("utf-8"), salt)
    return (hashed, salt) if gened_salt else hashed
